@@ -21,6 +21,7 @@
 #include "templateloader.h"
 #include "engine.h"
 #include "exception.h"
+#include "grantlee_latin1literal_p.h"
 
 #include <QtCore/QFile>
 #include <QtCore/QFileInfo>
@@ -79,7 +80,7 @@ bool FileSystemTemplateLoader::canLoadTemplate( const QString &name ) const
     if ( i >= m_templateDirs.size() )
       break;
 
-    file.setFileName( m_templateDirs.at( i ) + '/' + m_themeName + '/' + name );
+    file.setFileName( m_templateDirs.at( i ) + QLatin1Char( '/' ) + m_themeName + QLatin1Char( '/' ) + name );
     ++i;
   }
 
@@ -99,8 +100,8 @@ Template FileSystemTemplateLoader::loadByName( const QString &fileName, Engine c
     if ( i >= m_templateDirs.size() )
       break;
 
-    file.setFileName( m_templateDirs.at( i ) + '/' + m_themeName + '/' + fileName );
-    QFileInfo fi( file );
+    file.setFileName( m_templateDirs.at( i ) + QLatin1Char( '/' ) + m_themeName + QLatin1Char( '/' ) + fileName );
+    const QFileInfo fi( file );
 
     if ( file.exists() &&
           !fi.canonicalFilePath().contains( QDir( m_templateDirs.at( i ) ).canonicalPath() ) )
@@ -112,9 +113,11 @@ Template FileSystemTemplateLoader::loadByName( const QString &fileName, Engine c
     return Template();
   }
 
-  QString content;
-  content = file.readAll();
-  return engine->newTemplate( content, fileName );
+  QTextStream fstream( &file );
+  fstream.setCodec( "UTF-8" );
+  const QString fileContent = fstream.readAll();
+
+  return engine->newTemplate( fileContent, fileName );
 }
 
 QPair<QString, QString> FileSystemTemplateLoader::getMediaUri( const QString& fileName ) const
@@ -125,9 +128,9 @@ QPair<QString, QString> FileSystemTemplateLoader::getMediaUri( const QString& fi
     if ( i >= m_templateDirs.size() )
       break;
 
-    file.setFileName( m_templateDirs.at( i ) + '/' + m_themeName + '/' + fileName );
+    file.setFileName( m_templateDirs.at( i ) + QLatin1Char( '/' ) + m_themeName + QLatin1Char( '/' ) + fileName );
 
-    QFileInfo fi( file );
+    const QFileInfo fi( file );
     if ( !fi.canonicalFilePath().contains( QDir( m_templateDirs.at( i ) ).canonicalPath() ) )
     {
       ++i;
@@ -135,7 +138,6 @@ QPair<QString, QString> FileSystemTemplateLoader::getMediaUri( const QString& fi
     }
 
     if ( file.exists() ) {
-      QFileInfo fi( file );
       QString path = fi.absoluteFilePath();
       path.chop( fileName.size() );
       return qMakePair( path, fileName );
@@ -159,10 +161,9 @@ bool InMemoryTemplateLoader::canLoadTemplate( const QString &name ) const
 Template InMemoryTemplateLoader::loadByName( const QString& name, Engine const *engine ) const
 {
   if ( m_namedTemplates.contains( name ) ) {
-    Template t = engine->newTemplate( m_namedTemplates.value( name ), name );
-    return t;
+    return engine->newTemplate( m_namedTemplates.value( name ), name );
   }
-  throw Grantlee::Exception( TagSyntaxError, QString( "Couldn't load template %1. Template does not exist." ).arg( name ) );
+  throw Grantlee::Exception( TagSyntaxError, QString::fromLatin1( "Couldn't load template %1. Template does not exist." ).arg( name ) );
 }
 
 QPair<QString, QString> InMemoryTemplateLoader::getMediaUri( const QString& fileName ) const
