@@ -20,13 +20,16 @@
 
 #include "util.h"
 #include "metaenumvariable_p.h"
+#include "grantlee_latin1literal_p.h"
+
+#include <QStringList>
 
 QString Grantlee::unescapeStringLiteral( const QString &input )
 {
   return input.mid( 1, input.size() - 2 )
-         .replace( "\\\'", QChar( '\'' ) )
-         .replace( "\\\"", QChar( '"' ) )
-         .replace( "\\\\", QChar( '\\' ) );
+         .replace( QLatin1String( "\\\'" ), QChar::fromLatin1( '\'' ) )
+         .replace( QLatin1String( "\\\"" ), QChar::fromLatin1( '"' ) )
+         .replace( QLatin1String( "\\\\" ), QChar::fromLatin1( '\\' ) );
 }
 
 bool Grantlee::variantIsTrue( const QVariant &variant )
@@ -62,8 +65,7 @@ bool Grantlee::variantIsTrue( const QVariant &variant )
   }
   }
 
-  Grantlee::SafeString str = getSafeString( variant );
-  return !str.get().isEmpty();
+  return !getSafeString( variant ).get().isEmpty();
 }
 
 QVariantList Grantlee::variantToList( const QVariant &var )
@@ -76,8 +78,15 @@ QVariantList Grantlee::variantToList( const QVariant &var )
     return var.toList();
   }
 
+  if ( var.type() == QVariant::StringList ) {
+    QVariantList list;
+    foreach(const QString &_string, var.toStringList())
+      list << _string;
+    return list;
+  }
+
   if ( var.type() == QVariant::Hash ) {
-    QVariantHash varHash = var.toHash();
+    const QVariantHash varHash = var.toHash();
     QVariantList list;
 
     QVariantHash::const_iterator it = varHash.constBegin();
@@ -88,7 +97,7 @@ QVariantList Grantlee::variantToList( const QVariant &var )
   }
 
   if ( var.userType() == qMetaTypeId<MetaEnumVariable>() ) {
-    MetaEnumVariable mev = var.value<MetaEnumVariable>();
+    const MetaEnumVariable mev = var.value<MetaEnumVariable>();
     if (mev.value != -1)
       return QVariantList();
 
@@ -138,12 +147,12 @@ Grantlee::SafeString Grantlee::getSafeString( const QVariant &input )
 
 bool Grantlee::isSafeString( const QVariant &input )
 {
-  int type = input.userType();
+  const int type = input.userType();
   return (( type == qMetaTypeId<Grantlee::SafeString>() )
           || type == QVariant::String );
 }
 
-bool Grantlee::supportedOutputType( const QVariant &input )
+static QList<int> getPrimitives()
 {
   QList<int> primitives;
   primitives << qMetaTypeId<Grantlee::SafeString>()
@@ -151,6 +160,12 @@ bool Grantlee::supportedOutputType( const QVariant &input )
              << QVariant::Int
              << QVariant::Double
              << QVariant::DateTime;
+  return primitives;
+}
+
+bool Grantlee::supportedOutputType( const QVariant &input )
+{
+  static const QList<int> primitives = getPrimitives();
   return primitives.contains( input.userType() );
 }
 
@@ -188,25 +203,32 @@ bool Grantlee::equals( const QVariant &lhs, const QVariant &rhs )
 
 Grantlee::SafeString Grantlee::toString( const QVariantList &list )
 {
-  QString output( '[' );
+  QString output( QLatin1Char( '[' ) );
   QVariantList::const_iterator it = list.constBegin();
   const QVariantList::const_iterator end = list.constEnd();
   while ( it != end ) {
-    QVariant item = *it;
+    const QVariant item = *it;
     if ( isSafeString( item ) ) {
-      output.append( "u\'" );
-      output.append( getSafeString( item ) );
-      output.append( '\'' );
-      if (( it + 1 ) != end )
-        output.append( ", " );
+      output += QLatin1Literal( "u\'" )
+              + static_cast<QString>( getSafeString( item ).get() )
+              + QLatin1Char( '\'' );
+    }
+    if ( ( item.type() == QVariant::Int )
+      || ( item.type() == QVariant::UInt )
+      || ( item.type() == QVariant::Double )
+      || ( item.type() == QVariant::LongLong )
+      || ( item.type() == QVariant::ULongLong )
+    ) {
+      output += item.toString();
     }
     if ( item.type() == QVariant::List ) {
-      output.append( toString( item.toList() ) );
-      output.append( ", " );
+      output += static_cast<QString>( toString( item.toList() ).get() );
     }
+    if ( ( it + 1 ) != end )
+      output += QLatin1String( ", " );
     ++it;
   }
 
-  return output.append( ']' );
+  return output.append( QLatin1Char( ']' ) );
 }
 
