@@ -68,13 +68,13 @@ void TestHtmlOutput::testSingleFormat()
   QTextDocument *doc = new QTextDocument();
 
   // One format
-  doc->setHtml( "This <b>text</b> is bold." );
+  doc->setHtml( QLatin1String( "This <b>text</b> is bold." ) );
 
     TextHTMLBuilder *hb = new TextHTMLBuilder();
     MarkupDirector *md = new MarkupDirector(hb);
     md->processDocument(doc);
     QString result = hb->getResult();
-    QRegExp regex(QString("^<p>This <strong>text</strong> is bold.</p>\\n$"));
+    QRegExp regex(QLatin1String("^<p>This <strong>text</strong> is bold.</p>\\n$"));
 
     QVERIFY(regex.exactMatch(result));
 
@@ -85,13 +85,13 @@ void TestHtmlOutput::testDoubleFormat()
     QTextDocument *doc = new QTextDocument();
 
     // One format
-    doc->setHtml("Some <b><i>formatted</i></b> text.");
+    doc->setHtml( QLatin1String( "Some <b><i>formatted</i></b> text." ) );
 
     TextHTMLBuilder *hb = new TextHTMLBuilder();
     MarkupDirector *md = new MarkupDirector(hb);
     md->processDocument(doc);
     QString result = hb->getResult();
-    QRegExp regex(QString("^<p>Some (<strong><em>|<em><strong>)formatted(</em></strong>|</strong></em>) text.</p>\\n$"));
+    QRegExp regex(QLatin1String("^<p>Some (<strong><em>|<em><strong>)formatted(</em></strong>|</strong></em>) text.</p>\\n$"));
 
     QVERIFY(regex.exactMatch(result));
 
@@ -100,14 +100,14 @@ void TestHtmlOutput::testDoubleFormat()
 void TestHtmlOutput::testAnchor()
 {
     QTextDocument *doc = new QTextDocument();
-    doc->setHtml("A <a href=\"http://www.kde.org\">link</a> to KDE.");
+    doc->setHtml( QLatin1String( "A <a href=\"http://www.kde.org\">link</a> to KDE." ) );
 
     TextHTMLBuilder *hb = new TextHTMLBuilder();
     MarkupDirector *md = new MarkupDirector(hb);
     md->processDocument(doc);
     QString result = hb->getResult();
 
-    QRegExp regex(QString("^<p>A <a href=\"http://www.kde.org\">link</a> to KDE.</p>\\n$"));
+    QRegExp regex(QLatin1String("^<p>A <a href=\"http://www.kde.org\">link</a> to KDE.</p>\\n$"));
 
     QVERIFY(regex.exactMatch(result));
 
@@ -116,14 +116,14 @@ void TestHtmlOutput::testAnchor()
 void TestHtmlOutput::testAnchorWithFormattedContent()
 {
     QTextDocument *doc = new QTextDocument();
-    doc->setHtml("A <a href=\"http://www.kde.org\"><b>formatted</b> link</a> to KDE.");
+    doc->setHtml( QLatin1String( "A <a href=\"http://www.kde.org\"><b>formatted</b> link</a> to KDE." ) );
 
     TextHTMLBuilder *hb = new TextHTMLBuilder();
     MarkupDirector *md = new MarkupDirector(hb);
     md->processDocument(doc);
     QString result = hb->getResult();
 
-    QRegExp regex(QString("^<p>A <a href=\"http://www.kde.org\"><strong>formatted</strong> link</a> to KDE.</p>\\n$"));
+    QRegExp regex(QLatin1String("^<p>A <a href=\"http://www.kde.org\"><strong>formatted</strong> link</a> to KDE.</p>\\n$"));
 
     QVERIFY(regex.exactMatch(result));
 
@@ -132,14 +132,14 @@ void TestHtmlOutput::testAnchorWithFormattedContent()
 void TestHtmlOutput::testAdjacentAnchors()
 {
     QTextDocument *doc = new QTextDocument();
-    doc->setHtml("Two <a href=\"http://www.kde.org\">links</a><a href=\"http://www.google.com\">next</a> to eachother.");
+    doc->setHtml( QLatin1String( "Two <a href=\"http://www.kde.org\">links</a><a href=\"http://www.google.com\">next</a> to eachother." ) );
 
     TextHTMLBuilder *hb = new TextHTMLBuilder();
     MarkupDirector *md = new MarkupDirector(hb);
     md->processDocument(doc);
     QString result = hb->getResult();
 
-    QRegExp regex(QString("^<p>Two <a href=\"http://www.kde.org\">links</a><a href=\"http://www.google.com\">next</a> to eachother.</p>\\n$"));
+    QRegExp regex(QLatin1String("^<p>Two <a href=\"http://www.kde.org\">links</a><a href=\"http://www.google.com\">next</a> to eachother.</p>\\n$"));
 
     QVERIFY(regex.exactMatch(result));
 }
@@ -147,14 +147,14 @@ void TestHtmlOutput::testAdjacentAnchors()
 void TestHtmlOutput::testNestedFormatting()
 {
     QTextDocument *doc = new QTextDocument();
-    doc->setHtml("This <b>text is <i>italic</i> and</b> bold.");
+    doc->setHtml( QLatin1String( "This <b>text is <i>italic</i> and</b> bold." ) );
 
     TextHTMLBuilder *hb = new TextHTMLBuilder();
     MarkupDirector *md = new MarkupDirector(hb);
     md->processDocument(doc);
     QString result = hb->getResult();
 
-    QRegExp regex(QString("^<p>This <strong>text is <em>italic</em> and</strong> bold.</p>\\n$"));
+    QRegExp regex(QLatin1String("^<p>This <strong>text is <em>italic</em> and</strong> bold.</p>\\n$"));
 
     QVERIFY(regex.exactMatch(result));
 }
@@ -162,14 +162,14 @@ void TestHtmlOutput::testNestedFormatting()
 void TestHtmlOutput::testSpan()
 {
     QTextDocument *doc = new QTextDocument();
-    doc->setHtml("Some <span style=\"color:#ff0000;\">formatted</span> text.");
+    doc->setHtml( QLatin1String( "Some <span style=\"color:#ff0000;\">formatted</span> text." ) );
 
     TextHTMLBuilder *hb = new TextHTMLBuilder();
     MarkupDirector *md = new MarkupDirector(hb);
     md->processDocument(doc);
     QString result = hb->getResult();
 
-    QRegExp regex = QRegExp("^<p>Some <span style=\"color:#ff0000;\">formatted</span> text.</p>\\n$");
+    QRegExp regex = QRegExp( QLatin1String( "^<p>Some <span style=\"color:#ff0000;\">formatted</span> text.</p>\\n$" ) );
 
     QVERIFY(regex.exactMatch(result));
 }
@@ -177,14 +177,14 @@ void TestHtmlOutput::testSpan()
 void TestHtmlOutput::testDoubleSpan()
 {
     QTextDocument *doc = new QTextDocument();
-    doc->setHtml("Some <span style=\"color:#ff0000;background-color:#00ff00;\">formatted</span> text.");
+    doc->setHtml( QLatin1String( "Some <span style=\"color:#ff0000;background-color:#00ff00;\">formatted</span> text." ) );
 
     TextHTMLBuilder *hb = new TextHTMLBuilder();
     MarkupDirector *md = new MarkupDirector(hb);
     md->processDocument(doc);
     QString result = hb->getResult();
 
-    QRegExp regex = QRegExp("^<p>Some <span style=\"(color:#ff0000|background-color:#00ff00);\"><span style=\"(color:#ff0000|background-color:#00ff00);\">formatted</span></span> text.</p>\\n$");
+    QRegExp regex = QRegExp( QLatin1String( "^<p>Some <span style=\"(color:#ff0000|background-color:#00ff00);\"><span style=\"(color:#ff0000|background-color:#00ff00);\">formatted</span></span> text.</p>\\n$" ) );
 
     QVERIFY(regex.exactMatch(result));
 
@@ -193,14 +193,14 @@ void TestHtmlOutput::testDoubleSpan()
 void TestHtmlOutput::testSpanNesting()
 {
     QTextDocument *doc = new QTextDocument();
-    doc->setHtml("Paragraph <span style=\"background-color:#00ff00;\">with some <span style=\"color:#ff0000;\">formatted</span> nested</span> text.");
+    doc->setHtml( QLatin1String( "Paragraph <span style=\"background-color:#00ff00;\">with some <span style=\"color:#ff0000;\">formatted</span> nested</span> text." ) );
 
     TextHTMLBuilder *hb = new TextHTMLBuilder();
     MarkupDirector *md = new MarkupDirector(hb);
     md->processDocument(doc);
     QString result = hb->getResult();
 
-    QRegExp regex = QRegExp("^<p>Paragraph <span style=\"background-color:#00ff00;\">with some <span style=\"color:#ff0000;\">formatted</span> nested</span> text.</p>\\n$");
+    QRegExp regex = QRegExp( QLatin1String( "^<p>Paragraph <span style=\"background-color:#00ff00;\">with some <span style=\"color:#ff0000;\">formatted</span> nested</span> text.</p>\\n$" ) );
 
     QVERIFY(regex.exactMatch(result));
 }
@@ -208,14 +208,14 @@ void TestHtmlOutput::testSpanNesting()
 void TestHtmlOutput::testDoubleStartDifferentFinish()
 {
     QTextDocument *doc = new QTextDocument();
-    doc->setHtml("Paragraph <i><b>with</b> some formatted</i> text.");
+    doc->setHtml( QLatin1String( "Paragraph <i><b>with</b> some formatted</i> text." ) );
 
     TextHTMLBuilder *hb = new TextHTMLBuilder();
     MarkupDirector *md = new MarkupDirector(hb);
     md->processDocument(doc);
     QString result = hb->getResult();
 
-    QRegExp regex = QRegExp("^<p>Paragraph <em><strong>with</strong> some formatted</em> text.</p>\\n$");
+    QRegExp regex = QRegExp( QLatin1String( "^<p>Paragraph <em><strong>with</strong> some formatted</em> text.</p>\\n$" ) );
 
     QVERIFY(regex.exactMatch(result));
 }
@@ -223,14 +223,14 @@ void TestHtmlOutput::testDoubleStartDifferentFinish()
 void TestHtmlOutput::testDoubleStartDifferentFinishReverseOrder()
 {
     QTextDocument *doc = new QTextDocument();
-    doc->setHtml("Paragraph <b><i>with</i> some formatted</b> text.");
+    doc->setHtml( QLatin1String( "Paragraph <b><i>with</i> some formatted</b> text." ) );
 
     TextHTMLBuilder *hb = new TextHTMLBuilder();
     MarkupDirector *md = new MarkupDirector(hb);
     md->processDocument(doc);
     QString result = hb->getResult();
 
-    QRegExp regex = QRegExp("^<p>Paragraph <strong><em>with</em> some formatted</strong> text.</p>\\n$");
+    QRegExp regex = QRegExp( QLatin1String( "^<p>Paragraph <strong><em>with</em> some formatted</strong> text.</p>\\n$" ) );
 
     QVERIFY(regex.exactMatch(result));
 
@@ -239,14 +239,14 @@ void TestHtmlOutput::testDoubleStartDifferentFinishReverseOrder()
 void TestHtmlOutput::testDifferentStartDoubleFinish()
 {
     QTextDocument *doc = new QTextDocument();
-    doc->setHtml("Paragraph <i>with some <b>formatted<b></i> text.");
+    doc->setHtml( QLatin1String( "Paragraph <i>with some <b>formatted<b></i> text." ) );
 
     TextHTMLBuilder *hb = new TextHTMLBuilder();
     MarkupDirector *md = new MarkupDirector(hb);
     md->processDocument(doc);
     QString result = hb->getResult();
 
-    QRegExp regex = QRegExp("^<p>Paragraph <em>with some <strong>formatted</strong></em> text.</p>\\n$");
+    QRegExp regex = QRegExp( QLatin1String( "^<p>Paragraph <em>with some <strong>formatted</strong></em> text.</p>\\n$" ) );
 
     QVERIFY(regex.exactMatch(result));
 }
@@ -254,14 +254,14 @@ void TestHtmlOutput::testDifferentStartDoubleFinish()
 void TestHtmlOutput::testDifferentStartDoubleFinishReverseOrder()
 {
     QTextDocument *doc = new QTextDocument();
-    doc->setHtml("Paragraph <b>with some <i>formatted</i></b> text.");
+    doc->setHtml( QLatin1String( "Paragraph <b>with some <i>formatted</i></b> text." ) );
 
     TextHTMLBuilder *hb = new TextHTMLBuilder();
     MarkupDirector *md = new MarkupDirector(hb);
     md->processDocument(doc);
     QString result = hb->getResult();
 
-    QRegExp regex = QRegExp("^<p>Paragraph <strong>with some <em>formatted</em></strong> text.</p>\\n$");
+    QRegExp regex = QRegExp( QLatin1String( "^<p>Paragraph <strong>with some <em>formatted</em></strong> text.</p>\\n$" ) );
 
     QVERIFY(regex.exactMatch(result));
 
@@ -270,14 +270,14 @@ void TestHtmlOutput::testDifferentStartDoubleFinishReverseOrder()
 void TestHtmlOutput::testOverlap()
 {
     QTextDocument *doc = new QTextDocument();
-    doc->setHtml("Paragraph <b>with <i>some</i></b><i> formatted</i> text.");
+    doc->setHtml( QLatin1String( "Paragraph <b>with <i>some</i></b><i> formatted</i> text." ) );
 
     TextHTMLBuilder *hb = new TextHTMLBuilder();
     MarkupDirector *md = new MarkupDirector(hb);
     md->processDocument(doc);
     QString result = hb->getResult();
 
-    QRegExp regex = QRegExp("^<p>Paragraph <strong>with <em>some</em></strong><em> formatted</em> text.</p>\\n$");
+    QRegExp regex = QRegExp( QLatin1String( "^<p>Paragraph <strong>with <em>some</em></strong><em> formatted</em> text.</p>\\n$" ) );
 
     QVERIFY(regex.exactMatch(result));
 
@@ -286,14 +286,14 @@ void TestHtmlOutput::testOverlap()
 void TestHtmlOutput::testEdgeCaseLeft()
 {
     QTextDocument *doc = new QTextDocument();
-    doc->setHtml("Paragraph <b>with some formatted text.</b>");
+    doc->setHtml( QLatin1String( "Paragraph <b>with some formatted text.</b>" ) );
 
     TextHTMLBuilder *hb = new TextHTMLBuilder();
     MarkupDirector *md = new MarkupDirector(hb);
     md->processDocument(doc);
     QString result = hb->getResult();
 
-    QRegExp regex = QRegExp("^<p>Paragraph <strong>with some formatted text.</strong></p>\\n$");
+    QRegExp regex = QRegExp( QLatin1String( "^<p>Paragraph <strong>with some formatted text.</strong></p>\\n$" ) );
 
     QVERIFY(regex.exactMatch(result));
 }
@@ -301,14 +301,14 @@ void TestHtmlOutput::testEdgeCaseLeft()
 void TestHtmlOutput::testEdgeCaseRight()
 {
     QTextDocument *doc = new QTextDocument();
-    doc->setHtml("<b>Paragraph with some formatted</b> text.");
+    doc->setHtml( QLatin1String( "<b>Paragraph with some formatted</b> text." ) );
 
     TextHTMLBuilder *hb = new TextHTMLBuilder();
     MarkupDirector *md = new MarkupDirector(hb);
     md->processDocument(doc);
     QString result = hb->getResult();
 
-    QRegExp regex = QRegExp("^<p><strong>Paragraph with some formatted</strong> text.</p>\\n$");
+    QRegExp regex = QRegExp( QLatin1String( "^<p><strong>Paragraph with some formatted</strong> text.</p>\\n$" ) );
 
     QVERIFY(regex.exactMatch(result));
 }
@@ -316,14 +316,14 @@ void TestHtmlOutput::testEdgeCaseRight()
 void TestHtmlOutput::testImage()
 {
     QTextDocument *doc = new QTextDocument();
-    doc->setHtml("Paragraph with an inline <img src=\"http://kde.org/img/kde41.png\" /> image.");
+    doc->setHtml( QLatin1String( "Paragraph with an inline <img src=\"http://kde.org/img/kde41.png\" /> image." ) );
 
     TextHTMLBuilder *hb = new TextHTMLBuilder();
     MarkupDirector *md = new MarkupDirector(hb);
     md->processDocument(doc);
     QString result = hb->getResult();
 
-    QRegExp regex = QRegExp("^<p>Paragraph with an inline <img src=\"http://kde.org/img/kde41.png\" /> image.</p>\\n$");
+    QRegExp regex = QRegExp( QLatin1String( "^<p>Paragraph with an inline <img src=\"http://kde.org/img/kde41.png\" /> image.</p>\\n$" ) );
 
     QVERIFY(regex.exactMatch(result));
 }
@@ -337,36 +337,36 @@ void TestHtmlOutput::testImageResized()
     QTextDocument *doc = new QTextDocument();
 
     // width
-    doc->setHtml("Paragraph with an inline <img src=\"http://kde.org/img/kde41.png\" width=\"10\" /> image.");
+    doc->setHtml( QLatin1String( "Paragraph with an inline <img src=\"http://kde.org/img/kde41.png\" width=\"10\" /> image." ) );
 
     hb = new TextHTMLBuilder();
     md = new MarkupDirector(hb);
     md->processDocument(doc);
     result = hb->getResult();
 
-    regex = QRegExp("^<p>Paragraph with an inline <img src=\"http://kde.org/img/kde41.png\" width=\"10\" /> image.</p>\\n$");
+    regex = QRegExp( QLatin1String( "^<p>Paragraph with an inline <img src=\"http://kde.org/img/kde41.png\" width=\"10\" /> image.</p>\\n$" ) );
     QVERIFY(regex.exactMatch(result));
 
     // height
-    doc->setHtml("Paragraph with an inline <img src=\"http://kde.org/img/kde41.png\" height=\"10\" /> image.");
+    doc->setHtml( QLatin1String( "Paragraph with an inline <img src=\"http://kde.org/img/kde41.png\" height=\"10\" /> image." ) );
 
     hb = new TextHTMLBuilder();
     md = new MarkupDirector(hb);
     md->processDocument(doc);
     result = hb->getResult();
 
-    regex = QRegExp("^<p>Paragraph with an inline <img src=\"http://kde.org/img/kde41.png\" height=\"10\" /> image.</p>\\n$");
+    regex = QRegExp( QLatin1String( "^<p>Paragraph with an inline <img src=\"http://kde.org/img/kde41.png\" height=\"10\" /> image.</p>\\n$" ) );
     QVERIFY(regex.exactMatch(result));
 
     // height and width
-    doc->setHtml("Paragraph with an inline <img src=\"http://kde.org/img/kde41.png\" height=\"10\" width=\"10\" /> image.");
+    doc->setHtml( QLatin1String( "Paragraph with an inline <img src=\"http://kde.org/img/kde41.png\" height=\"10\" width=\"10\" /> image." ) );
 
     hb = new TextHTMLBuilder();
     md = new MarkupDirector(hb);
     md->processDocument(doc);
     result = hb->getResult();
 
-    regex = QRegExp("^<p>Paragraph with an inline <img src=\"http://kde.org/img/kde41.png\" width=\"10\" height=\"10\" /> image.</p>\\n$");
+    regex = QRegExp( QLatin1String( "^<p>Paragraph with an inline <img src=\"http://kde.org/img/kde41.png\" width=\"10\" height=\"10\" /> image.</p>\\n$" ) );
 
     QVERIFY(regex.exactMatch(result));
 }
@@ -381,105 +381,105 @@ void TestHtmlOutput::testEachFormatTagSingly()
 
 
     // Test bold
-    doc->setHtml("Some <b>formatted</b> text.");
+    doc->setHtml( QLatin1String( "Some <b>formatted</b> text." ) );
     hb = new TextHTMLBuilder();
     md = new MarkupDirector(hb);
     md->processDocument(doc);
     result = hb->getResult();
 
-    regex = QRegExp("^<p>Some <strong>formatted</strong> text.</p>\\n$");
+    regex = QRegExp( QLatin1String( "^<p>Some <strong>formatted</strong> text.</p>\\n$" ) );
     QVERIFY(regex.exactMatch(result));
 
 
     // Test Italic
-    doc->setHtml("Some <i>formatted</i> text.");
+    doc->setHtml( QLatin1String( "Some <i>formatted</i> text." ) );
     hb = new TextHTMLBuilder();
     md = new MarkupDirector(hb);
     md->processDocument(doc);
     result = hb->getResult();
 
-    regex = QRegExp("^<p>Some <em>formatted</em> text.</p>\\n$");
+    regex = QRegExp( QLatin1String( "^<p>Some <em>formatted</em> text.</p>\\n$" ) );
     QVERIFY(regex.exactMatch(result));
 
     // Test Underline
-    doc->setHtml("Some <u>formatted</u> text.");
+    doc->setHtml( QLatin1String( "Some <u>formatted</u> text." ) );
     hb = new TextHTMLBuilder();
     md = new MarkupDirector(hb);
     md->processDocument(doc);
     result = hb->getResult();
 
-    regex = QRegExp("^<p>Some <u>formatted</u> text.</p>\\n$");
+    regex = QRegExp( QLatin1String( "^<p>Some <u>formatted</u> text.</p>\\n$" ) );
     QVERIFY(regex.exactMatch(result));
 
     // Test Strikeout
-    doc->setHtml("Some <s>formatted</s> text.");
+    doc->setHtml( QLatin1String( "Some <s>formatted</s> text." ) );
     hb = new TextHTMLBuilder();
     md = new MarkupDirector(hb);
     md->processDocument(doc);
     result = hb->getResult();
 
-    regex = QRegExp("^<p>Some <s>formatted</s> text.</p>\\n$");
+    regex = QRegExp( QLatin1String( "^<p>Some <s>formatted</s> text.</p>\\n$" ) );
     QVERIFY(regex.exactMatch(result));
 
     // Test Superscript
-    doc->setHtml("Some <sup>formatted</sup> text.");
+    doc->setHtml( QLatin1String( "Some <sup>formatted</sup> text." ) );
     hb = new TextHTMLBuilder();
     md = new MarkupDirector(hb);
     md->processDocument(doc);
     result = hb->getResult();
 
-    regex = QRegExp("^<p>Some <sup>formatted</sup> text.</p>\\n$");
+    regex = QRegExp( QLatin1String( "^<p>Some <sup>formatted</sup> text.</p>\\n$" ) );
     QVERIFY(regex.exactMatch(result));
 
     // Test Subscript
-    doc->setHtml("Some <sub>formatted</sub> text.");
+    doc->setHtml( QLatin1String( "Some <sub>formatted</sub> text." ) );
     hb = new TextHTMLBuilder();
     md = new MarkupDirector(hb);
     md->processDocument(doc);
     result = hb->getResult();
 
-    regex = QRegExp("^<p>Some <sub>formatted</sub> text.</p>\\n$");
+    regex = QRegExp( QLatin1String( "^<p>Some <sub>formatted</sub> text.</p>\\n$" ) );
     QVERIFY(regex.exactMatch(result));
 
     // Test Foreground
-    doc->setHtml("Some <span style=\"color:#ff0000;\">formatted</span> text.");
+    doc->setHtml( QLatin1String( "Some <span style=\"color:#ff0000;\">formatted</span> text." ) );
     hb = new TextHTMLBuilder();
     md = new MarkupDirector(hb);
     md->processDocument(doc);
     result = hb->getResult();
 
-    regex = QRegExp("^<p>Some <span style=\"color:#ff0000;\">formatted</span> text.</p>\\n$");
+    regex = QRegExp( QLatin1String( "^<p>Some <span style=\"color:#ff0000;\">formatted</span> text.</p>\\n$" ) );
     QVERIFY(regex.exactMatch(result));
 
 
     // Test Background
-    doc->setHtml("Some <span style=\"background-color:#ff0000;\">formatted</span> text.");
+    doc->setHtml( QLatin1String( "Some <span style=\"background-color:#ff0000;\">formatted</span> text." ) );
     hb = new TextHTMLBuilder();
     md = new MarkupDirector(hb);
     md->processDocument(doc);
     result = hb->getResult();
 
-    regex = QRegExp("^<p>Some <span style=\"background-color:#ff0000;\">formatted</span> text.</p>\\n$");
+    regex = QRegExp( QLatin1String( "^<p>Some <span style=\"background-color:#ff0000;\">formatted</span> text.</p>\\n$" ) );
     QVERIFY(regex.exactMatch(result));
 
     // Test Font Family
-    doc->setHtml("Some <span style=\"font-family:courier;\">formatted</span> text.");
+    doc->setHtml( QLatin1String( "Some <span style=\"font-family:courier;\">formatted</span> text." ) );
     hb = new TextHTMLBuilder();
     md = new MarkupDirector(hb);
     md->processDocument(doc);
     result = hb->getResult();
 
-    regex = QRegExp("^<p>Some <span style=\"font-family:courier;\">formatted</span> text.</p>\\n$");
+    regex = QRegExp( QLatin1String( "^<p>Some <span style=\"font-family:courier;\">formatted</span> text.</p>\\n$" ) );
     QVERIFY(regex.exactMatch(result));
 
     // Test Font Size
-    doc->setHtml("Some <span style=\"font-size:20pt;\">formatted</span> text.");
+    doc->setHtml( QLatin1String( "Some <span style=\"font-size:20pt;\">formatted</span> text." ) );
     hb = new TextHTMLBuilder();
     md = new MarkupDirector(hb);
     md->processDocument(doc);
     result = hb->getResult();
 
-    regex = QRegExp("^<p>Some <span style=\"font-size:20pt;\">formatted</span> text.</p>\\n$");
+    regex = QRegExp( QLatin1String( "^<p>Some <span style=\"font-size:20pt;\">formatted</span> text.</p>\\n$" ) );
     QVERIFY(regex.exactMatch(result));
 
 }
@@ -487,14 +487,14 @@ void TestHtmlOutput::testEachFormatTagSingly()
 void TestHtmlOutput::testHorizontalRule()
 {
     QTextDocument *doc = new QTextDocument();
-    doc->setHtml("<p style=\"margin-top:0;margin-bottom:0;\">Foo</p><hr /><p style=\"margin-top:0;margin-bottom:0;\">Bar</p>");
+    doc->setHtml( QLatin1String( "<p style=\"margin-top:0;margin-bottom:0;\">Foo</p><hr /><p style=\"margin-top:0;margin-bottom:0;\">Bar</p>" ) );
 
     TextHTMLBuilder *hb = new TextHTMLBuilder();
     MarkupDirector *md = new MarkupDirector(hb);
     md->processDocument(doc);
     QString result = hb->getResult();
 
-    QRegExp regex = QRegExp("^<p>Foo</p>\\n<hr />\\n<p>Bar</p>\\n$");
+    QRegExp regex = QRegExp( QLatin1String( "^<p>Foo</p>\\n<hr />\\n<p>Bar</p>\\n$" ) );
 
     QVERIFY(regex.exactMatch(result));
 }
@@ -502,14 +502,14 @@ void TestHtmlOutput::testHorizontalRule()
 void TestHtmlOutput::testNewlines()
 {
     QTextDocument *doc = new QTextDocument();
-    doc->setHtml("<p>Foo<br /><br />\n<p>Bar</p>");
+    doc->setHtml( QLatin1String( "<p>Foo<br /><br />\n<p>Bar</p>" ) );
 
     TextHTMLBuilder *hb = new TextHTMLBuilder();
     MarkupDirector *md = new MarkupDirector(hb);
     md->processDocument(doc);
     QString result = hb->getResult();
 
-    QRegExp regex = QRegExp("^<p>Foo</p>\\n<p>&nbsp;<p>&nbsp;</p>\\n<p>Bar</p>\\n$");
+    QRegExp regex = QRegExp( QLatin1String( "^<p>Foo</p>\\n<p>&nbsp;<p>&nbsp;</p>\\n<p>Bar</p>\\n$" ) );
 
     QVERIFY(regex.exactMatch(result));
 }
@@ -520,18 +520,18 @@ void TestHtmlOutput::testNewlinesThroughQTextEdit()
     QTextEdit *te = new QTextEdit();
     QTextCursor cursor = te->textCursor();
     cursor.movePosition(QTextCursor::Start);
-    cursor.insertText("Foo");
-    cursor.insertText("\n");
-    cursor.insertText("\n");
-    cursor.insertText("\n");
-    cursor.insertText("Bar");
+    cursor.insertText( QLatin1String( "Foo" ) );
+    cursor.insertText( QLatin1String( "\n" ) );
+    cursor.insertText( QLatin1String( "\n" ) );
+    cursor.insertText( QLatin1String( "\n" ) );
+    cursor.insertText( QLatin1String( "Bar" ) );
 
     TextHTMLBuilder *hb = new TextHTMLBuilder();
     MarkupDirector *md = new MarkupDirector(hb);
     md->processDocument(te->document());
     QString result = hb->getResult();
 
-    QRegExp regex = QRegExp("^<p>Foo</p>\\n<p>&nbsp;<p>&nbsp;<p>Bar</p>\\n$");
+    QRegExp regex = QRegExp( QLatin1String( "^<p>Foo</p>\\n<p>&nbsp;<p>&nbsp;<p>Bar</p>\\n$" ) );
 
     QVERIFY(regex.exactMatch(result));
 }
